@@ -365,7 +365,7 @@ void KbfxConfigApp::KbfxNewsBrowserLoad()
 		browser->view()->resize ( KBFXNewsBrowser->width(), KBFXNewsBrowser->height() );
 		browser->view()->setVScrollBarMode ( TQScrollView::AlwaysOff );
 		browser->view()->setHScrollBarMode ( TQScrollView::AlwaysOff );
-		browser->view()->setFocusPolicy ( TQ_NoFocus );
+		browser->view()->setFocusPolicy ( TQWidget::NoFocus );
 		browser->view()->show();
 
 		connect ( browser->browserExtension(),
