@@ -82,42 +82,42 @@ bool KbfxConfigDlgAbout::eventFilter ( TQObject *obj, TQEvent *ev )
 
 	if ( ev->type() == TQEvent::FocusIn || ev->type() == TQEvent::Enter )
 	{
-		if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelNookie) )
+		if ( obj == KbfxPixmapLabelNookie )
 		{
 			KbfxTeamInfo->setText ( KbfxMemberTextNookie );
 			KbfxUnmarkAllPixmaps();
 			KbfxPixmapLabelNookie->setFrameShape ( TQFrame::WinPanel );
 			return TRUE;
 		}
-		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelSiraj) )
+		else if ( obj == KbfxPixmapLabelSiraj )
 		{
 			KbfxTeamInfo->setText ( KbfxMemberTextSiraj );
 			KbfxUnmarkAllPixmaps();
 			KbfxPixmapLabelSiraj->setFrameShape ( TQFrame::WinPanel );
 			return TRUE;
 		}
-		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelNathanael) )
+		else if ( obj == KbfxPixmapLabelNathanael )
 		{
 			KbfxTeamInfo->setText ( KbfxMemberTextNathanael );
 			KbfxUnmarkAllPixmaps();
 			KbfxPixmapLabelNathanael->setFrameShape ( TQFrame::WinPanel );
 			return TRUE;
 		}
-		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelPhobosK) )
+		else if ( obj == KbfxPixmapLabelPhobosK )
 		{
 			KbfxTeamInfo->setText ( KbfxMemberTextPhobosK );
 			KbfxUnmarkAllPixmaps();
 			KbfxPixmapLabelPhobosK->setFrameShape ( TQFrame::WinPanel );
 			return TRUE;
 		}
-		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelJohnny) )
+		else if ( obj == KbfxPixmapLabelJohnny )
 		{
 			KbfxTeamInfo->setText ( KbfxMemberTextJohnny );
 			KbfxUnmarkAllPixmaps();
 			KbfxPixmapLabelJohnny->setFrameShape ( TQFrame::WinPanel );
 			return TRUE;
 		}
-		else if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(KbfxPixmapLabelEphracis) )
+		else if ( obj == KbfxPixmapLabelEphracis )
 		{
 			KbfxTeamInfo->setText ( KbfxMemberTextEphracis );
 			KbfxUnmarkAllPixmaps();
