@@ -26,7 +26,7 @@ KbfxPushButton::KbfxPushButton ( TQWidget *parent, const char *name )
 {
 	setText ( "P R E V I E W" );
 	setToggleButton ( TRUE );
-	setFocusPolicy ( TQ_NoFocus );
+	setFocusPolicy ( TQWidget::NoFocus );
 }
 
 KbfxPushButton::~KbfxPushButton()
