@@ -69,23 +69,23 @@ void KbfxButton::loadSkins()
 		: TQImage ( ConfigInit ().m_KbfxNormalButtonPathDefault );
 
 	TQSize _sizeNormal = _tmpNormal.size();
-	_tmpHover = _tmpHover.smoothScale ( _sizeNormal, TQ_ScaleFree );
-	_tmpPressed = _tmpPressed.smoothScale ( _sizeNormal, TQ_ScaleFree );
+	_tmpHover = _tmpHover.smoothScale ( _sizeNormal, TQImage::ScaleFree );
+	_tmpPressed = _tmpPressed.smoothScale ( _sizeNormal, TQImage::ScaleFree );
 
 
 	if ( !m_kicker_auto_adjust )
 	{
 		if ( m_sizeHeight )
 		{
-			_tmpHover = _tmpHover.smoothScale ( _tmpHover.width(), m_size, TQ_ScaleMin );
-			_tmpPressed = _tmpPressed.smoothScale ( _tmpPressed.width(), m_size, TQ_ScaleMin );
-			_tmpNormal = _tmpNormal.smoothScale ( _tmpNormal.width(), m_size, TQ_ScaleMin );
+			_tmpHover = _tmpHover.smoothScale ( _tmpHover.width(), m_size, TQImage::ScaleMin );
+			_tmpPressed = _tmpPressed.smoothScale ( _tmpPressed.width(), m_size, TQImage::ScaleMin );
+			_tmpNormal = _tmpNormal.smoothScale ( _tmpNormal.width(), m_size, TQImage::ScaleMin );
 		}
 		else
 		{
-			_tmpHover = _tmpHover.smoothScale ( m_size, _tmpHover.height(), TQ_ScaleMin );
-			_tmpPressed = _tmpPressed.smoothScale ( m_size, _tmpPressed.height(), TQ_ScaleMin );
-			_tmpNormal = _tmpNormal.smoothScale ( m_size, _tmpNormal.height(), TQ_ScaleMin );
+			_tmpHover = _tmpHover.smoothScale ( m_size, _tmpHover.height(), TQImage::ScaleMin );
+			_tmpPressed = _tmpPressed.smoothScale ( m_size, _tmpPressed.height(), TQImage::ScaleMin );
+			_tmpNormal = _tmpNormal.smoothScale ( m_size, _tmpNormal.height(), TQImage::ScaleMin );
 		}
 	}
 	m_over_skin = TQPixmap ( _tmpHover );
