@@ -80,7 +80,7 @@ KbfxSpinxMenuWidget::init()
 	m_search = new TQLineEdit ( this, "Search BOX" );
 	TQToolTip::add( m_search, tr2i18n( "Type here to search..." ) );
 	m_search->setFrameShape ( TQFrame::NoFrame );
-	m_search->setFocusPolicy ( TQ_StrongFocus );
+	m_search->setFocusPolicy ( TQWidget::StrongFocus );
 	m_search->move ( ConfigInit ().m_searchBox_x + m_searchTag->width (),
 	                 ConfigInit ().m_searchBox_y );
 	m_search->resize ( ConfigInit ().m_searchBox_w - m_searchTag->width (),
@@ -238,7 +238,7 @@ KbfxSpinxMenuWidget::createMask ()
 	rawimg =
 	    rawimg.smoothScale ( ConfigInit ().m_userMenuWidth,
 	                   ConfigInit ().m_userMenuHeight,
-	                   TQ_ScaleFree );
+	                   TQImage::ScaleFree );
 
 	maskpng.convertFromImage ( rawimg );
 
