@@ -30,7 +30,7 @@ KbfxSpinxScrollBar::KbfxSpinxScrollBar ( TQWidget * parent, const char *name, in
         m_normal = ( *KbfxPlasmaPixmapProvider::pixmap ( "scrollnormalbot" ) );
     }
         TQImage _tmp_img = m_normal.convertToImage();
-	_tmp_img = _tmp_img.smoothScale ( ConfigInit().m_itemView_w, m_normal.height (),TQ_ScaleFree );
+	_tmp_img = _tmp_img.smoothScale ( ConfigInit().m_itemView_w, m_normal.height (),TQImage::ScaleFree );
 	m_normal = TQPixmap ( _tmp_img );
 
 	this->resize ( m_normal.width (), m_normal.height () );
