@@ -85,7 +85,7 @@ KbfxSpinxToolButton::setPixmaps ( TQPixmap normal, TQPixmap hover )
 {
 	TQSize _sizeNormal = normal.size();
 	TQImage _tmpHover = hover.convertToImage ();
-	_tmpHover = _tmpHover.smoothScale ( _sizeNormal, TQ_ScaleFree );
+	_tmpHover = _tmpHover.smoothScale ( _sizeNormal, TQImage::ScaleFree );
 
 	m_normal = normal;
 	m_hover = TQPixmap ( _tmpHover );
